@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "eca" "0.6.0"
+(define-package "eca" "20251119.1624"
   "AI pair programming via ECA (Editor Code Assistant)."
   '((emacs         "28.1")
     (dash          "2.18.0")
@@ -7,8 +7,8 @@
     (markdown-mode "2.3")
     (compat        "30.1"))
   :url "https://github.com/editor-code-assistant/eca-emacs"
-  :commit "e444685f386b245fecfee28253032ce880c6ded5"
-  :revdesc "e444685f386b"
+  :commit "a48a6b6430bf9c658d71bb2f08d1a90517a4563d"
+  :revdesc "a48a6b6430bf"
   :keywords '("tools")
   :authors '(("Eric Dallo" . "ercdll1337@gmail.com"))
   :maintainers '(("Eric Dallo" . "ercdll1337@gmail.com")))
