@@ -87,11 +87,8 @@
   ;; The servers and their status.
   (tool-servers '())
 
-  ;; The supported chat agents by the server.
-  (chat-agents nil)
-
-  ;; The available variants for the current model.
-  (chat-variants '())
+  ;; The supported chat behaviors by the server.
+  (chat-behaviors nil)
 
   ;; The welcome message for new chats.
   (chat-welcome-message ""))
@@ -169,10 +166,11 @@
   "Convert a file URI to a file path."
   (cond
    ((string-prefix-p "file:///" uri)
-    (url-unhex-string (substring uri 7)))
+    (url-unhex-string (substring uri 8)))
 
    ((string-prefix-p "file://" uri)
-    (url-unhex-string (substring uri 6)))
+    (url-unhex-string (substring uri 7)))
+
 
    (t uri)))
 
@@ -219,26 +217,26 @@ Inheirits BASE-MAP."
     ("p" "Repeat prompt" eca-chat-repeat-prompt)
     ("C" "Clear prompt" eca-chat-clear-prompt)
     ("m" "Select model" eca-chat-select-model)
-    ("v" "Select variant" eca-chat-select-variant)
-    ("b" "Change agent" eca-chat-select-agent)
+    ("b" "Change behavior" eca-chat-select-behavior)
     ("o" "Open/close chat window" eca-chat-toggle-window)
     ("a" "Accept all pending tool calls" eca-chat-tool-call-accept-all)
-    ("!" "Accept all pending tool calls and remember" eca-chat-tool-call-accept-all-and-remember)
-    ("s" "Add to system prompt" eca-chat-add-context-to-system-prompt)
-    ("u" "Add to user prompt" eca-chat-add-context-to-user-prompt)
-    ("d" "Drop from system prompt" eca-chat-drop-context-from-system-prompt)
+    ("s" "Accept all pending tool calls and remember" eca-chat-tool-call-accept-all-and-remember)
     ("A" "Accept next pending tool call" eca-chat-tool-call-accept-next)]
 
    ["Navigation"
-    ("N h" "Message history" eca-chat-timeline)
-    ("N c" "Chat" eca)
-    ("N m" "MCP details" eca-mcp-details)
-    ("N e" "Show stderr (logs)" eca-show-stderr)
-    ("N E" "Show emacs errors" eca-show-errors)]
+    ("h" "Message history" eca-chat-timeline)
+    ("c" "Chat" eca)
+    ("M" "MCP details" eca-mcp-details)
+    ("E" "Show stderr (logs)" eca-show-stderr)]
+
+   ["Context"
+    ("s" "Add to system prompt" eca-chat-add-context-to-system-prompt)
+    ("u" "Add to user prompt" eca-chat-add-context-to-user-prompt)
+    ("d" "Drop from system prompt" eca-chat-drop-context-from-system-prompt)]
 
    ["Server"
-    ("S r" "Restart" eca-restart)
-    ("S s" "Stop" eca-stop)]])
+    ("R" "Restart" eca-restart)
+    ("S" "Stop" eca-stop)]])
 
 (provide 'eca-util)
 ;;; eca-util.el ends here
